==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/id.js <==
OC.L10N.register(
    "workflowengine",
    {
    "File MIME type" : "Berkas tipe MIME",
    "is" : "adalah",
    "is not" : "bukan",
    "matches" : "cocok dengan",
    "does not match" : "tidak cocok dengan",
    "Example: {placeholder}" : "Contoh: {placeholder}",
    "File size (upload)" : "Ukuran berkas (unggah)",
    "less" : "kurang dari",
    "less or equals" : "kurang dari atau sama dengan",
    "greater or equals" : "lebih dari atau sama dengan",
    "greater" : "lebih dari",
    "File system tag" : "Tag sistem berkas",
    "is tagged with" : "di tag dengan",
    "is not tagged with" : "tidak di tag dengan",
    "Select tag…" : "Pilih tag...",
    "Request remote address" : "Minta alamat remote",
    "matches IPv4" : "cocok dengan IPv4",
    "does not match IPv4" : "tidak cocok dengan IPv4",
    "matches IPv6" : "cocok dengan IPv6",
    "does not match IPv6" : "tidak cocok dengan IPv6",
    "Request time" : "Waktu permintaan",
    "between" : "diantara",
    "not between" : "tidak diantara",
    "Start" : "Mulai",
    "End" : "Selesai",
    "Select timezone…" : "Pilih zona waktu...",
    "Request URL" : "Minta URL",
    "Predefined URLs" : "URL terdefinisi",
    "Files WebDAV" : "Berkas WebDAV",
    "Request user agent" : "Minta user agent",
    "Sync clients" : "Klien sync",
    "Android client" : "Klien Android",
    "iOS client" : "Klien iOS",
    "Desktop client" : "Klien desktop",
    "User group membership" : "Keanggotaan grup pengguna",
    "is member of" : "anggota dari",
    "is not member of" : "bukan anggota dari",
    "Short rule description" : "Deskripsi aturan singkat",
    "Add rule" : "Tambahkan aturan",
    "Reset" : "Setel ulang",
    "Save" : "Simpan",
    "Saving…" : "Menyimpan...",
    "Saved" : "Disimpan",
    "Saving failed:" : "Penyimpanan gagal:",
    "Add rule group" : "Tambahkan aturan grup ",
    "The given operator is invalid" : "Operator yang diberikan tidak sah",
    "The given regular expression is invalid" : "Regular expression yang diberikan tidak sah",
    "The given file size is invalid" : "Ukuran berkas yang diberikan tidak sah",
    "The given tag id is invalid" : "Tag ID yang diberikan tidak sah",
    "The given IP range is invalid" : "Rentang IP yang diberikan tidak sah",
    "The given IP range is not valid for IPv4" : "Rentang IP yang diberikan tidak sah untuk IPv4",
    "The given IP range is not valid for IPv6" : "Rentang IP yang diberikan tidak sah untuk IPv6",
    "The given time span is invalid" : "Rentang waktu yang diberikan tidak sah",
    "The given start time is invalid" : "Waktu mulai yang diberikan tidak sah",
    "The given end time is invalid" : "Waktu selesai yang diberikan tidak sah",
    "The given group does not exist" : "Grup yang diberikan tidak ada",
    "Check %s is invalid or does not exist" : "Cek %s tidak valid atau tidak ada",
    "Operation #%s does not exist" : "Operasi #%s tidak ada",
    "Operation %s does not exist" : "Operasi %s tidak ada",
    "Operation %s is invalid" : "Operasi %s tidak valid",
    "Check %s does not exist" : "Cek %s tidak ada",
    "Check %s is invalid" : "Cek %s tidak valid",
    "Check #%s does not exist" : "Cek #%s tidak ada",
    "Open documentation" : "Buka dokumentasi",
    "Loading…" : "Memuat...",
    "Workflow" : "Alur kerja"
},
"nplurals=1; plural=0;");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/id.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Operator yang diberikan tidak sah",
    "The given regular expression is invalid" : "Regular expression yang diberikan tidak sah",
    "The given file size is invalid" : "Ukuran berkas yang diberikan tidak sah",
    "The given tag id is invalid" : "Tag ID yang diberikan tidak sah",
    "The given IP range is invalid" : "Rentang IP yang diberikan tidak sah",
    "The given IP range is not valid for IPv4" : "Rentang IP yang diberikan tidak sah untuk IPv4",
    "The given IP range is not valid for IPv6" : "Rentang IP yang diberikan tidak sah untuk IPv6",
    "The given time span is invalid" : "Rentang waktu yang diberikan tidak sah",
    "The given start time is invalid" : "Waktu mulai yang diberikan tidak sah",
    "The given end time is invalid" : "Waktu selesai yang diberikan tidak sah",
    "The given group does not exist" : "Grup yang diberikan tidak ada",
    "Operation #%s does not exist" : "Operasi #%s tidak ada",
    "Operation %s does not exist" : "Operasi %s tidak ada",
    "Operation %s is invalid" : "Operasi %s tidak valid",
    "Check %s does not exist" : "Cek %s tidak ada",
    "Check %s is invalid" : "Cek %s tidak valid",
    "Check #%s does not exist" : "Cek #%s tidak ada",
    "Check %s is invalid or does not exist" : "Cek %s tidak valid atau tidak ada",
    "Predefined URLs" : "URL terdefinisi",
    "Files WebDAV" : "Berkas WebDAV",
    "Android client" : "Klien Android",
    "iOS client" : "Klien iOS",
    "Desktop client" : "Klien desktop",
    "is" : "adalah",
    "is not" : "bukan",
    "matches" : "cocok dengan",
    "does not match" : "tidak cocok dengan",
    "File MIME type" : "Berkas tipe MIME",
    "File size (upload)" : "Ukuran berkas (unggah)",
    "less" : "kurang dari",
    "less or equals" : "kurang dari atau sama dengan",
    "greater or equals" : "lebih dari atau sama dengan",
    "greater" : "lebih dari",
    "Request remote address" : "Minta alamat remote",
    "matches IPv4" : "cocok dengan IPv4",
    "does not match IPv4" : "tidak cocok dengan IPv4",
    "matches IPv6" : "cocok dengan IPv6",
    "does not match IPv6" : "tidak cocok dengan IPv6",
    "File system tag" : "Tag sistem berkas",
    "is tagged with" : "di tag dengan",
    "is not tagged with" : "tidak di tag dengan",
    "Request URL" : "Minta URL",
    "Request time" : "Waktu permintaan",
    "between" : "diantara",
    "not between" : "tidak diantara",
    "Request user agent" : "Minta user agent",
    "User group membership" : "Keanggotaan grup pengguna",
    "is member of" : "anggota dari",
    "is not member of" : "bukan anggota dari",
    "Short rule description" : "Deskripsi aturan singkat",
    "Add rule" : "Tambahkan aturan",
    "Reset" : "Setel ulang",
    "Save" : "Simpan",
    "Saving…" : "Menyimpan...",
    "Saved" : "Disimpan",
    "Saving failed:" : "Penyimpanan gagal:",
    "Add rule group" : "Tambahkan aturan grup ",
    "Example: {placeholder}" : "Contoh: {placeholder}",
    "Select tag…" : "Pilih tag...",
    "Start" : "Mulai",
    "End" : "Selesai",
    "Select timezone…" : "Pilih zona waktu...",
    "Sync clients" : "Klien sync",
    "Workflow" : "Alur kerja",
    "Open documentation" : "Buka dokumentasi",
    "Loading…" : "Memuat..."
},
"nplurals=1; plural=0;");
